database.to.graph: Creates an igraph object from a thread in the database

Description Usage Arguments Value

Description

Creates an igraph object from a thread in the database

Usage

1
database.to.graph(idthread, con, dataset)

Arguments

idthread

thread id

con

RSQlite connection to a database

dataset

name of the forum

Value

a tree graph of the thread


alumbreras/rlumbreras documentation built on May 12, 2019, 1:38 a.m.