plot.threadgraph: Plots the user and the tree posts graph of a thread

Description Usage Arguments

Description

Plots the user and the tree posts graph of a thread

Usage

1
2
## S3 method for class 'threadgraph'
plot(threadgraph, title = "")

Arguments

threadgraph

a list with a $gu (users) graph and $gp (posts) graph

title

plot title


alumbreras/rlumbreras documentation built on May 12, 2019, 1:38 a.m.