plot.tree: Plots a discussion tree using nice parameters

Description Usage Arguments Details

Description

Plots a discussion tree using nice parameters

Usage

1
2
## S3 method for class 'tree'
plot(gtree, labels = c("name", "id"))

Arguments

gtree

an igraph object with a tree structure (no cicles)

labels

the type of label to be shown over vertices (if any)

Details

This is a function to fast plot the structure of conversations. If 'label' is NA then no label is used.


alumbreras/rlumbreras documentation built on May 12, 2019, 1:38 a.m.