Description Usage Arguments Details
Plots a discussion tree using nice parameters
1 2 |
gtree |
an igraph object with a tree structure (no cicles) |
labels |
the type of label to be shown over vertices (if any) |
This is a function to fast plot the structure of conversations. If 'label' is NA then no label is used.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.